# WARNING!
# THIS IS AN AUTOGENERATED FILE!
# MANUAL CHANGES CAN AND WILL BE OVERWRITTEN!

import re
from pathlib import Path

from setuptools import setup

PACKAGE_NAME = 'libpurple_to_markdown'

PACKAGE_DESCRIPTION = """
# Markdown Message Conversion.

Conversion script from various messaging formats to markdown.

Supported input formats:

- [Pidgin/Libpurple](https://pidgin.im/) chat program HTML-based logs. **This
  backend is not actively maintained.**
- [SyncTech Backup & Restore](https://www.synctech.com.au/sms-backup-restore/)
  XML-based backup format.

## Motivation

Messaging applications are mostly good at sending real-time messages to other
people, but they generally do not possess any useful archival features. Most
messages are write-once read-once, and the apps where built for this use case.
More and more through, I am attracted to the prospect of archival; of
understanding who I am and who I _were_ when I wrote those messages.

I recently discovered [Obsidian](https://obsidian.md) and liked the prospect of
cross-referencing my notes with my old chat logs. Libpurple uses HTML logs if
you haven't configured it to something else (which I haden't).

I no longer use IRC or Pidgin as my entire friend group have switched to using
Matrix.

## Usage

There are two main import patterns:

- One-off archival import: For when you have a large set of messages to import
  for a service that you don't use very much anymore.
- Recurring import: For when you are still using the service, and want to
  import on a recurring basis.

This program will be default not overwrite existing files, as the user might
have modified it.

Special consideration must be taking for recurring imports if you expect to be
modifying the resulting files, for example if you are inserting links
using Obsidian's unlinked mentions feature. You might want to use the
`--skip-this-period` flag to avoid importing the current period until it has
become the last period. That way you won't accidentally modify the log, because
it has been finalized.

### One-off

This is the recommended command for the one-off case:

```bash
python -m libpurple_to_markdown LOG_DIRECTORY --output OUTPUT_FOLDER
```

### Recurring

This is the recommended command for the recurring import case:

```bash
python -m libpurple_to_markdown LOG_DIRECTORY --output OUTPUT_FOLDER --skip-this-period --period month
```

## TODO

- [ ] SyncTech: Decode MMS parts and reconstruct image attachments.
""".strip()

PACKAGE_DESCRIPTION_SHORT = """
Conversion script from various messaging formats to markdown.""".strip()


def parse_version_file(text: str) -> str:
    text = re.sub('^#.*', '', text, flags=re.MULTILINE)
    match = re.match(r'^\s*__version__\s*=\s*(["\'])([\d\.]+)\1$', text)
    if match is None:
        msg = 'Malformed _version.py file!'
        raise Exception(msg)
    return match.group(2)


def find_python_packages() -> list[str]:
    """Find all python packages (directories containing __init__.py files)."""
    root_path = Path(PACKAGE_NAME)
    packages: set[str] = {PACKAGE_NAME}

    # Search recursively
    for init_file in root_path.rglob('__init__.py'):
        packages.add(str(init_file.parent).replace('/', '.'))

    return sorted(packages)


with open(PACKAGE_NAME + '/_version.py') as f:
    version = parse_version_file(f.read())


REQUIREMENTS_MAIN = [
    'beautifulsoup4',
]
REQUIREMENTS_TEST = []


setup(
    name=PACKAGE_NAME,
    version=version,
    description=PACKAGE_DESCRIPTION_SHORT,
    long_description=PACKAGE_DESCRIPTION,
    long_description_content_type='text/markdown',
    author='Jon Michael Aanes',
    author_email='jonjmaa@gmail.com',
    url='https://gitfub.space/Jmaa/' + PACKAGE_NAME,
    packages=find_python_packages(),
    install_requires=REQUIREMENTS_MAIN,
    extras_require={
        'test': REQUIREMENTS_TEST,
    },
    python_requires='>=3.9',
)
